==> haskell-unliftio-0.2.19-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unliftio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unliftio
version:              0.2.19
visibility:           public
id:                   unliftio-0.2.19-eC3J1Kp2ltE0HGPdpPs99
key:                  unliftio-0.2.19-eC3J1Kp2ltE0HGPdpPs99
license:              MIT
copyright:            2017 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Francesco Mazzoli
homepage:
    https://github.com/fpco/unliftio/tree/master/unliftio#readme

synopsis:
    The MonadUnliftIO typeclass for unlifting monads to IO (batteries included)

description:
    Please see the documentation and README at <https://www.stackage.org/package/unliftio>

category:             Control
abi:                  52ea86b82ce167a6c24d34bb2d953105
exposed:              True
exposed-modules:
    UnliftIO UnliftIO.Async UnliftIO.Chan UnliftIO.Concurrent
    UnliftIO.Directory UnliftIO.Environment UnliftIO.Exception
    UnliftIO.Foreign UnliftIO.IO UnliftIO.IO.File UnliftIO.IORef
    UnliftIO.Internals.Async UnliftIO.MVar UnliftIO.Memoize
    UnliftIO.Process UnliftIO.QSem UnliftIO.QSemN UnliftIO.STM
    UnliftIO.Temporary UnliftIO.Timeout

hidden-modules:       Paths_unliftio UnliftIO.IO.File.Posix
import-dirs:          /usr/lib/ghc-9.0.1/site-local/unliftio-0.2.19
library-dirs:         /usr/lib/ghc-9.0.1/site-local/unliftio-0.2.19
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/unliftio-0.2.19
hs-libraries:         HSunliftio-0.2.19-eC3J1Kp2ltE0HGPdpPs99
depends:
    async-2.2.3-JYKLQKS337YI3EHAC7DhtO base-4.15.0.0
    bytestring-0.10.12.1 deepseq-1.4.5.0 directory-1.3.6.1
    filepath-1.4.2.1 process-1.6.11.0 stm-2.5.0.0 time-1.9.3
    transformers-0.5.6.2 unix-2.7.2.2
    unliftio-core-0.2.0.1-2baD1vXgUkB5a1NRn2rSLN

haddock-interfaces:   /usr/share/doc/haskell-unliftio/html/unliftio.haddock
haddock-html:         /usr/share/doc/haskell-unliftio/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unliftio-0.2.19-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unliftio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unliftio
version:              0.2.19
visibility:           public
id:                   unliftio-0.2.19-EaAoBBmefhjF6biHLTEG3M
key:                  unliftio-0.2.19-EaAoBBmefhjF6biHLTEG3M
license:              MIT
copyright:            2017 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Francesco Mazzoli
homepage:
    https://github.com/fpco/unliftio/tree/master/unliftio#readme

synopsis:
    The MonadUnliftIO typeclass for unlifting monads to IO (batteries included)

description:
    Please see the documentation and README at <https://www.stackage.org/package/unliftio>

category:             Control
abi:                  6233348a2e800a1b4c2da867cda96d7c
exposed:              True
exposed-modules:
    UnliftIO UnliftIO.Async UnliftIO.Chan UnliftIO.Concurrent
    UnliftIO.Directory UnliftIO.Environment UnliftIO.Exception
    UnliftIO.Foreign UnliftIO.IO UnliftIO.IO.File UnliftIO.IORef
    UnliftIO.Internals.Async UnliftIO.MVar UnliftIO.Memoize
    UnliftIO.Process UnliftIO.QSem UnliftIO.QSemN UnliftIO.STM
    UnliftIO.Temporary UnliftIO.Timeout

hidden-modules:       Paths_unliftio UnliftIO.IO.File.Posix
import-dirs:          /usr/lib/ghc-9.0.1/site-local/unliftio-0.2.19
library-dirs:         /usr/lib/ghc-9.0.1/site-local/unliftio-0.2.19
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/unliftio-0.2.19
hs-libraries:         HSunliftio-0.2.19-EaAoBBmefhjF6biHLTEG3M
depends:
    async-2.2.3-JYKLQKS337YI3EHAC7DhtO base-4.15.0.0
    bytestring-0.10.12.1 deepseq-1.4.5.0 directory-1.3.6.1
    filepath-1.4.2.1 process-1.6.11.0 stm-2.5.0.0 time-1.9.3
    transformers-0.5.6.2 unix-2.7.2.2
    unliftio-core-0.2.0.1-2baD1vXgUkB5a1NRn2rSLN

haddock-interfaces:   /usr/share/doc/haskell-unliftio/html/unliftio.haddock
haddock-html:         /usr/share/doc/haskell-unliftio/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
